==> core-1.0.7-RC5-sources.jar: commonMain/io/data2viz/charts/config/CursorConfig.kt <==
package io.data2viz.charts.config

import io.data2viz.charts.chart.internal.CursorImpl
import io.data2viz.charts.core.CursorType
import io.data2viz.charts.core.ExperimentalCharts
import io.data2viz.charts.core.Stroke
import io.data2viz.charts.core.UserAction
import io.data2viz.charts.layout.DrawingZone
import io.data2viz.geom.Point

/**
 * A decorator lambda is called for the cursor, use this to draw custom cursors.
 *
 * @param position the expected position where the cursor should appear (relative to the [drawingZone] coordinates)
 * @param drawingZone the drawing zone on which to draw the decorator
 */
public typealias CursorDecorator = (position: Point, drawingZone: DrawingZone) -> Unit

/**
 * The configuration interface for a [CursorImpl].
 */
public interface CursorConfig : Stroke {

    /**
     * Show / hide the [CursorImpl].
     */
    public var show: Boolean

    /**
     * Type of [CursorImpl]: horizontal, vertical or crosshair.
     */
    public var type: CursorType

    /**
     * Default action that will trigger the cursor display.
     * Default value is CursorBind.Highlight, meaning that the cursor, if available, will display when highlighting.
     */
    public var bindCursorOn: CursorBind

    /**
     * The cursor decorator lambda will be called on cursor display, use this to draw custom cursors.
     */
    @ExperimentalCharts
    public var cursorDecorator: CursorDecorator?

}

public enum class CursorBind {

    /**
     * Bind the cursor display to the default "highlight" action.
     */
    Highlight,

    /**
     * Bind the cursor display to the default "select" action.
     */
    Select,

    /**
     * Unbind the cursor to any default action, use this if you want to manage it yourself.
     */
    None
}

==> core-1.0.8-RC5-sources.jar: commonMain/io/data2viz/charts/config/CursorConfig.kt <==
package io.data2viz.charts.config

import io.data2viz.charts.chart.internal.CursorImpl
import io.data2viz.charts.core.*
import io.data2viz.charts.core.CursorType
import io.data2viz.charts.core.Stroke
import io.data2viz.charts.layout.DrawingZone
import io.data2viz.geom.Point

/**
 * A decorator lambda is called for the cursor, use this to draw custom cursors.
 *
 * @param datum the current element
 * @param position the expected position where the cursor should appear (relative to the [drawingZone] coordinates)
 * @param drawingZone the drawing zone on which to draw the decorator
 */
public typealias CursorDecorator<DOMAIN> = (datum: Datum<DOMAIN>, position: Point, drawingZone: DrawingZone) -> Unit

/**
 * The configuration interface for a [CursorImpl].
 */
public interface CursorConfig : Stroke {

    /**
     * Show / hide the [CursorImpl].
     */
    public var show: Boolean

    /**
     * Type of [CursorImpl]: horizontal, vertical or crosshair.
     */
    public var type: CursorType

    /**
     * Default action that will trigger the cursor display.
     * Default value is CursorBind.Highlight, meaning that the cursor, if available, will display when highlighting.
     */
    public var bindCursorOn: CursorBind

    /**
     * The cursor decorator lambda will be called on cursor display, use this to draw custom cursors.
     */
    @ExperimentalCharts
    public var cursorDecorator: CursorDecorator<*>?

}

public enum class CursorBind {

    /**
     * Bind the cursor display to the default "highlight" action.
     */
    Highlight,

    /**
     * Bind the cursor display to the default "select" action.
     */
    Select,

    /**
     * Unbind the cursor to any default action, use this if you want to manage it yourself.
     */
    None
}
